//
//  MMIError.h
//
//
//
//  Copyright 2005 __MyCompanyName__. All rights reserved.
//

//
// Copyright 2005-2007 MildMannered Industries. All right reserved.
// 
//
//

/*! @header MMIError.h
@discussion MMIError class.
*/


#import <Cocoa/Cocoa.h>


#define kMMIErrorEmergencyPriority 2.0
#define kMMIErrorNormalPriority 0.0






/*!
@class MMIError
@abstract MMIError extends NSError and provides some additional accessors, and static utility methods.
@discussion All MMIErrors have a title and description format. A number
of arguments may be required for the format. Utility methods are present, so that generally, the called
simply needs to supply the error code, and any objects to be inserted into the error description.
*/

@interface MMIError : NSError {
    float mPriority;   
}



/*!
@method initWithCode:title:description:
	@abstract Initialises the error with the specified code, title, and description.
	@discussion This is a designated intialiser for MMIError.
	@param theDomain The domain
	@param theCode The error code
	@param title The error title
	@param description The localized recovery description for the error.
 	@param help The help anchor for the error. 
	@result  Returns the newly initialized MMIError object or nil on error.
 */
- (id)initWithDomain:(NSString *)theDomain code:(int)theCode title:(NSString *)title description:(NSString *)description help:(NSString *)help priority:(float)priority;


/*!
@method initWithError:
	@abstract Initialises the error with the specified NSError object.
	@discussion Don't we need a domain here?
	@param error The NSError to use.
	@result  Returns the newly initialized MMIError object or nil on error.
 */
- (id)initWithError:(NSError *)error;


/*!
@method  error:withTitle:description:help:
	@abstract Static utility method that returns a newly allocated MMIError with the specified parameters.
	@discussion This method is used when the error description format requires no arguments.
	@param code The error code
	@param title The error title
	@param description The error description
 	@param help The help anchor for the error.
	@result  Returns the newly allocated and initialized MMIError object or nil on error.
 */
+ (MMIError *) errorWithDomain:(NSString *)theDomain code:(int)theCode withTitle:(NSString *) title description:(NSString *)description help:(NSString *)help priority:(float)priority;


/*!
@method error:
	@abstract Static utility method that returns a newly allocated MMIError with the specified parameters.
	@discussion Do we need a domain here?
	@param error The NSError to use.
	@result  Returns the newly allocated and initialized MMIError object or nil on error.
 */
+ (MMIError *)error:(NSError *)error;



/*!
@method errorDate
	@abstract Returns the date the error was created.
	@discussion All MMIErrors will have a valid non-nil date.
	@result  Returns the errors creation date.
 */
- (NSDate *) errorDate;


/*!
@method setPriority
	@abstract Sets the priority of the error.
	@discussion These are Growl priorities. The default value is 0; priority ranges from -2 (‘Very Low’) to 2 (‘Emergency’).
	@param  The error's priority.
 */
- (void) setPriority:(float) priority;

    
/*!
@method priority
	@abstract Returns the priority of the error.
	@discussion These are Growl priorities. The default value is 0; priority ranges from -2 (‘Very Low’) to 2 (‘Emergency’).
	@result  The error's priority.
 */
- (float) priority;


/*!
@method help
	@abstract Returns the help for the error, or nil if no help is set.
	@discussion This should be the value of the help anchor to show for the error.
	@result  Returns the help for the error, which may be nil.
 */
- (NSString *) help;


/*!
@method addHelp:ToAlert:
	@abstract Utility method that will add a help button to the alert.
	@discussion The help anchor may safely be nil. No help will be added.
	@param helpAnchor The help anchor.
	@param alert The alert.
 */
+ (void) addHelp:(NSString *) helpAnchor toAlert:(NSAlert *)alert;


/*!
@method descriptionForNetServicesError:
	@abstract Returns a description for the supplied error code.
	@discussion Returns a description for the define error code.
	@result  Returns a description for the supplied net services error.
 */
// + (NSString *)descriptionForNetServicesError:(int)errorCode;



@end
